@@ -3,7 +3,7 @@
 
 as.char <- function(object, maxlen=20)
 {
-    stopifnot(is.numeric(maxlen), length(maxlen) == 1, maxlen > 0)
+    check.integer.scalar(maxlen, min=1)
 
     if(is.null(object))
         "NULL"
@@ -15,7 +15,7 @@ as.char <- function(object, maxlen=20)
         environment.as.char(object)
 
     else if(is.call(object)) { # e.g. x is a call object in foo(x=1:3)
-        s <- strip.space(paste(format(object), collapse=""))
+        s <- strip.space.collapse(format(object))
         if(nchar(s) > maxlen)
             s <- paste0(substr(s, 1, maxlen), "...)")
         s
@@ -98,7 +98,7 @@ environment.as.char <- function(env, maxlen=60) # compact description
 print_summary <- function(x, xname=trunc.deparse(substitute(x)),
                           trace=2, msg="", prefix="", details=2)
 {
-    stopifnot(is.numeric(trace))
+    check.numeric.scalar(trace)
     if(trace < 2)
         return()
     if(is.null(x)) {
@@ -136,7 +136,7 @@ print_summary <- function(x, xname=trunc.deparse(substitute(x)),
     }
     df <- try(my.data.frame(x, trace, stringsAsFactors=FALSE), silent=TRUE)
     if(is.try.err(df)) { # be robust for whatever gets passed to this function
-        printf("print_summary: could not convert class \"%s\" to a data.frame\n",
+        printf("print_summary: cannot convert class \"%s\" to a data.frame\n",
                class(x)[1])
         printf("%s%s%s:\n", prefix, xname, msg)
         if(length(dim(x)) == 2) { # it's a matrix or other 2D object?
